pub trait Event {
type Item;
// Provided methods
fn into_process(self) -> EventIntoProcess<Self>
where Self: Sized { ... }
fn into_composite(self) -> EventIntoComposite<Self>
where Self: Sized { ... }
fn and_then<U, F>(self, f: F) -> AndThen<Self, U, F>
where Self: Sized,
U: Event,
F: FnOnce(Self::Item) -> U { ... }
fn map<B, F>(self, f: F) -> Map<Self, B, F>
where Self: Sized,
F: FnOnce(Self::Item) -> B { ... }
fn zip<U>(self, other: U) -> Zip<Self, U>
where Self: Sized,
U: Event { ... }
fn ap<U, B>(self, other: U) -> Ap<Self, U, B>
where Self: Sized,
Self::Item: FnOnce(U::Item) -> B,
U: Event { ... }
fn run_in_start_time(self) -> RunInStartTime<Self>
where Self: Sized { ... }
fn run_in_start_time_by(
self,
including_current_events: bool,
) -> RunInStartTime<Self>
where Self: Sized { ... }
fn run_in_stop_time(self) -> RunInStopTime<Self>
where Self: Sized { ... }
fn run_in_stop_time_by(
self,
including_current_events: bool,
) -> RunInStopTime<Self>
where Self: Sized { ... }
fn into_boxed(self) -> EventBox<Self::Item>
where Self: Sized + 'static { ... }
}Expand description
The computation synchronized with the event queue.
Required Associated Types
Provided Methods
Sourcefn into_process(self) -> EventIntoProcess<Self>where
Self: Sized,
fn into_process(self) -> EventIntoProcess<Self>where
Self: Sized,
Convert to the Process computation.
Sourcefn into_composite(self) -> EventIntoComposite<Self>where
Self: Sized,
fn into_composite(self) -> EventIntoComposite<Self>where
Self: Sized,
Convert to the Composite computation.
Sourcefn and_then<U, F>(self, f: F) -> AndThen<Self, U, F>
fn and_then<U, F>(self, f: F) -> AndThen<Self, U, F>
Bind the current computation with its continuation within the resulting computation.
Sourcefn map<B, F>(self, f: F) -> Map<Self, B, F>
fn map<B, F>(self, f: F) -> Map<Self, B, F>
Map the current computation using the specified transform.
Sourcefn zip<U>(self, other: U) -> Zip<Self, U>
fn zip<U>(self, other: U) -> Zip<Self, U>
Zip the current computation with another one within the resulting computation.
Sourcefn run_in_start_time(self) -> RunInStartTime<Self>where
Self: Sized,
fn run_in_start_time(self) -> RunInStartTime<Self>where
Self: Sized,
Run the computation in the start time.
Sourcefn run_in_start_time_by(
self,
including_current_events: bool,
) -> RunInStartTime<Self>where
Self: Sized,
fn run_in_start_time_by(
self,
including_current_events: bool,
) -> RunInStartTime<Self>where
Self: Sized,
Run the computation in the start time by processing the current events or not.
Sourcefn run_in_stop_time(self) -> RunInStopTime<Self>where
Self: Sized,
fn run_in_stop_time(self) -> RunInStopTime<Self>where
Self: Sized,
Run the computation in the stop time.
Sourcefn run_in_stop_time_by(
self,
including_current_events: bool,
) -> RunInStopTime<Self>where
Self: Sized,
fn run_in_stop_time_by(
self,
including_current_events: bool,
) -> RunInStopTime<Self>where
Self: Sized,
Run the computation in the stop time by processing the current events or not.
Sourcefn into_boxed(self) -> EventBox<Self::Item>where
Self: Sized + 'static,
fn into_boxed(self) -> EventBox<Self::Item>where
Self: Sized + 'static,
Convert into a boxed value.
Implementors
Sourceimpl Event for NewInIntegTimes
impl Event for NewInIntegTimes
type Item = ObservableBox<f64>
Sourceimpl Event for NewInStartTime
impl Event for NewInStartTime
type Item = ObservableBox<f64>
Sourceimpl Event for NewInStopTime
impl Event for NewInStopTime
type Item = ObservableBox<f64>
Sourceimpl Event for NewSourceInIntegTimes
impl Event for NewSourceInIntegTimes
Sourceimpl Event for NewSourceInStartTime
impl Event for NewSourceInStartTime
Sourceimpl Event for NewSourceInStopTime
impl Event for NewSourceInStopTime
Sourceimpl Event for DisposableEventRepr
Available on crate feature cons_mode only.
impl Event for DisposableEventRepr
Available on crate feature
cons_mode only.