pub fn embed_result_process<T>(val: Result<T>) -> EmbedResult<T>Expand description
Embeds the result value within the current process, which may cancel the process, for example.
pub fn embed_result_process<T>(val: Result<T>) -> EmbedResult<T>Embeds the result value within the current process, which may cancel the process, for example.