Stream

Enum Stream 

pub enum Stream<T> {
    Cons(ProcessBox<(T, Stream<T>)>),
}
An infinite stream of data.

Variants



Cons(ProcessBox<(T, Stream<T>)>)

The cons-cell.

Implementations

Source

impl<T> Stream<T>

pub fn run(self) -> ProcessBox<(T, Self)>

Run the stream computation.

pub fn map<F, B>(self, f: F) -> Stream<B>
where F: Fn(T) -> B + 'static, B: 'static, T: 'static,

Map the stream according the specified function.

pub fn mapc<F, M, B>(self, f: F) -> Stream<B>
where F: Fn(T) -> M + 'static, M: Event<Item = B> + 'static, B: 'static, T: 'static,

Compose the stream.

pub fn accum<F, M, B, Acc>(self, f: F, acc: Acc) -> Stream<B>
where F: Fn(Acc, T) -> M + 'static, M: Event<Item = (Acc, B)> + 'static, B: 'static, T: 'static, Acc: 'static,

Accumulator that outputs a value determined by the specified function.

pub fn filter<F>(self, pred: F) -> Self
where F: Fn(&T) -> bool + 'static, T: 'static,

Filter only those data values that satisfy to the specified predicate.

pub fn filterc<F, M>(self, pred: F) -> Self
where F: Fn(&T) -> M + 'static, M: Event<Item = bool> + 'static, T: 'static,

Filter only those data values that satisfy to the specified predicate.

pub fn take(self, n: isize) -> Self
where T: 'static,

Return the prefix of the stream of the specified length.

pub fn take_while<F>(self, pred: F) -> Self
where F: Fn(&T) -> bool + 'static, T: 'static,

Return the longest prefix of the stream of elements that satisfy the predicate.

pub fn take_while_c<F, M>(self, pred: F) -> Self
where F: Fn(&T) -> M + 'static, M: Event<Item = bool> + 'static, T: 'static,

Return the longest prefix of the stream of elements that satisfy the computations.

pub fn drop(self, n: isize) -> Self
where T: 'static,

Return the suffix of the stream after the specified first elements.

pub fn drop_while<F>(self, pred: F) -> Self
where F: Fn(&T) -> bool + 'static, T: 'static,

Return the suffix of the stream of elements remaining after take_while.

pub fn drop_while_c<F, M>(self, pred: F) -> Self
where F: Fn(&T) -> M + 'static, M: Event<Item = bool> + 'static, T: 'static,

Return the suffix of the stream of elements remaining after take_while_c.