pub trait Parameter {
type Item;
// Provided methods
fn into_simulation(self) -> ParameterIntoSimulation<Self>
where Self: Sized { ... }
fn into_event(self) -> ParameterIntoEvent<Self>
where Self: Sized { ... }
fn into_process(self) -> ParameterIntoProcess<Self>
where Self: Sized { ... }
fn into_composite(self) -> ParameterIntoComposite<Self>
where Self: Sized { ... }
fn and_then<U, F>(self, f: F) -> AndThen<Self, U, F>
where Self: Sized,
U: Parameter,
F: FnOnce(Self::Item) -> U { ... }
fn map<B, F>(self, f: F) -> Map<Self, B, F>
where Self: Sized,
F: FnOnce(Self::Item) -> B { ... }
fn zip<U>(self, other: U) -> Zip<Self, U>
where Self: Sized,
U: Parameter { ... }
fn ap<U, B>(self, other: U) -> Ap<Self, U, B>
where Self: Sized,
Self::Item: FnOnce(U::Item) -> B,
U: Parameter { ... }
fn into_boxed(self) -> ParameterBox<Self::Item>
where Self: Sized + 'static { ... }
}Expand description
The computation to define external parameters.
Required Associated Types
Provided Methods
Sourcefn into_simulation(self) -> ParameterIntoSimulation<Self>where
Self: Sized,
fn into_simulation(self) -> ParameterIntoSimulation<Self>where
Self: Sized,
Convert into the Simulation computation.
Sourcefn into_event(self) -> ParameterIntoEvent<Self>where
Self: Sized,
fn into_event(self) -> ParameterIntoEvent<Self>where
Self: Sized,
Convert into the Event computation.
Sourcefn into_process(self) -> ParameterIntoProcess<Self>where
Self: Sized,
fn into_process(self) -> ParameterIntoProcess<Self>where
Self: Sized,
Convert to the Process computation.
Sourcefn into_composite(self) -> ParameterIntoComposite<Self>where
Self: Sized,
fn into_composite(self) -> ParameterIntoComposite<Self>where
Self: Sized,
Convert into the Composite computation.
Sourcefn and_then<U, F>(self, f: F) -> AndThen<Self, U, F>
fn and_then<U, F>(self, f: F) -> AndThen<Self, U, F>
Bind the current computation with its continuation within the resulting computation.
Sourcefn map<B, F>(self, f: F) -> Map<Self, B, F>
fn map<B, F>(self, f: F) -> Map<Self, B, F>
Map the current computation using the specified transform.
Sourcefn zip<U>(self, other: U) -> Zip<Self, U>
fn zip<U>(self, other: U) -> Zip<Self, U>
Zip the current computation with another one within the resulting computation.
Sourcefn into_boxed(self) -> ParameterBox<Self::Item>where
Self: Sized + 'static,
fn into_boxed(self) -> ParameterBox<Self::Item>where
Self: Sized + 'static,
Convert into a boxed value.